#
# spec file for package conky
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1100
%define with_lua_extra 1
%else
%define with_lua_extra 0
%endif

Name:           conky
Version:        1.9.0
Release:        26.18
Summary:        Lightweight System Monitor
License:        GPL-3.0+ and LGPL-3.0+ and MIT
Group:          System/Monitoring
Url:            http://conky.sourceforge.net
Source:         http://prdownloads.sourceforge.net/conky/conky-%{version}.tar.bz2
Source1:        conky.desktop
# PATCH-FIX - add -lm when linking against -liw
Patch1:         conky-1.9.0-libiw_with_libm.patch
# PATCH-FIX-UPSTREAM - revert broken apcupsd to previous working version.
Patch2:         fix-apcupsd.patch
# PATCH-FIX-UPSTREAM - avoid rewriting an arbitrary user file. remove next release
Patch3:         fix-CVE-2011-3616.patch
Source99:       conky-rpmlintrc
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  pkgconfig
%if 0%{?suse_version} >= 1000
BuildRequires:  xorg-x11-devel
%else
BuildRequires:  XFree86-devel
%endif
%if 0%{?suse_version} >= 1120
BuildRequires:  libiw-devel
%else
BuildRequires:  wireless-tools
%endif
BuildRequires:  alsa-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cairo-devel
BuildRequires:  docbook2x
BuildRequires:  glib2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel
%if %with_lua_extra
BuildRequires:  tolua++
%endif
%if 0%{?sles_version} == 0 || 0%{?sles_version} >= 11
%define with_imlib2 1
BuildRequires:  imlib2-devel
%endif
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig(libxml-2.0)
%if 0%{?suse_version} >= 1020
%define with_lua 1
%if 0%{?suse_version} >= 1220
BuildRequires:  lua51-devel
%else
BuildRequires:  lua-devel
%endif
%endif
%if 0%{?suse_version} >= 1020 || 0%{?fedora_version} > 0
%if 0%{?sles_version} < 11
BuildRequires:  vim-enhanced
%else
BuildRequires:  vim
%endif
%else
BuildRequires:  vim
%endif
%if 0%{?suse_version} >= 1030
BuildRequires:  libcurl-devel
%else
BuildRequires:  curl-devel
%endif
%if 0%{?packman_bs}
BuildRequires:  audacious-devel
# fix dbus-glib-1 no found for audacious
BuildRequires:  dbus-1-glib-devel
BuildRequires:  libXNVCtrl
BuildRequires:  xmms2-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Conky is an advanced, highly configurable system monitor for X.

%if 0%{?packman_bs}
This package is built with support for audacious and nVidia GPUs.
%endif

%if %with_lua_extra
%package cairo
Summary:        Cairo Rendering Backend for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}

%description cairo
Conky is an advanced, highly configurable system monitor for X.
This package contains the Cairo rendering backend plugin
for %{name}.

%package imlib2
Summary:        Imlib2 Rendering Backend for %{name}
Group:          System/Monitoring
Requires:       %{name} = %{version}
# This is required for imlib2 function properly.
Requires:       imlib2-loaders

%description imlib2
Conky is an advanced, highly configurable system monitor for X.
This package contains the Imlib2 rendering backend plugin
for %{name}.
%endif

%package doc
Summary:        Documentation for conky
Group:          System/Monitoring

%description doc
Conky is an advanced, highly configurable system monitor for X.

This package provides additional documentation about conky in
the following directory:
    %{_docdir}/%{name}/

%package vim
Summary:        Conky Configuration File Support for Vim
Group:          Productivity/Editors/Vi
Requires:       vim-base

%description vim
Conky is an advanced, highly configurable system monitor for X.

This package provides syntax highlighting support for conky
configuration files in vim.

%package nano
Summary:        Conky Configuration File Support for nano
Group:          Productivity/Editors/Other
Requires:       nano

%description nano
Conky is an advanced, highly configurable system monitor for X.

This package provides syntax highlighting support for conky
configuration files in nano.

%if 0%{?packman_bs}
%package feature-audacious
Summary:        Pseudo Package for %{name} with Audacious Support
Group:          System/Monitoring
Requires:       %{name} = %{version}

%description feature-audacious
This is a pseudo-package that doesn't contain any files but
requires the Packman build of %{name}, which includes support
for the Audacious player.

%package feature-nvidia
Summary:        Pseudo Package for %{name} with nVidia Support
Group:          System/Monitoring
Requires:       %{name} = %{version}

%description feature-nvidia
This is a pseudo-package that doesn't contain any files but
requires the Packman build of %{name}, which includes support
for nVidia GPU statistics.

%endif
%prep
%setup -q

%patch1
%patch2 -p1
%patch3 -p1

for i in AUTHORS ChangeLog; do
    mv "${i}" "${i}.orig" && \
    iconv -f iso8859-1 -t utf8 -o "${i}" "${i}.orig" && \
    rm "${i}.orig"
done

%build
test -e ./configure || ./autogen.sh

LIBS="-lm"
export LIBS
# to link X11 libs on SLE < 11:
LIBS="$LIBS -L/usr/X11R6/%{_lib}"

LDFLAGS="-lm" \
%configure \
    --enable-xft \
    --enable-own-window \
    --enable-double-buffer \
    --enable-x11 \
    --enable-xdamage \
    --enable-portmon \
    --enable-ibm \
    --enable-weather-metar \
    --enable-weather-xoap \
    --enable-rss \
    --enable-eve \
    --%{?with_imlib2:enable}%{!?with_imlib2:disable}-imlib2 \
%if 0%{?with_lua}
    --enable-lua \
%if %with_lua_extra
    --enable-lua-imlib2 \
    --enable-lua-cairo \
%endif #with_lua_extra
%else
    --disable-lua \
    --disable-lua-imlib2 \
    --disable-lua-cairo \
%endif #with_lua
    --enable-alsa \
    --enable-wlan \
%if 0%{?packman_bs}
    --enable-audacious=yes \
    --enable-nvidia=yes \
    --enable-xmms2=yes
%else
    --enable-audacious=no \
    --enable-nvidia=no
%endif #packman_bs

# inotify on SLE < 11 is too old
%if 0%{?sles_version} > 0 && 0%{?sles_version} < 11
sed -i '/^#define HAVE_SYS_INOTIFY_H/d' src/config.h
echo '#undef HAVE_SYS_INOTIFY_H' >> src/config.h
%endif

make %{?_smp_flags}

%install
make DESTDIR=%{buildroot} install

install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%suse_update_desktop_file -r "%{name}" System Monitor

for feature in audacious nvidia; do
cat<<EOF >README.feature-"$feature"
This package acts as a placeholder for %{name} with
support for ${feature}, to avoid accidential removal
of that functionality through upgrading to a package
from a different repository.
EOF
done

install -D -m0644 extras/vim/ftdetect/conkyrc.vim "%{buildroot}%{_datadir}/vim/site/ftdetect/conkyrc.vim"
install -D -m0644 extras/vim/syntax/conkyrc.vim   "%{buildroot}%{_datadir}/vim/site/syntax/conkyrc.vim"

install -D -m0644 extras/nano/conky.nanorc "%{buildroot}%{_datadir}/nano/conky.nanorc"

install -d "%{buildroot}%{_docdir}/%{name}"
MAINDOCFILES="$PWD/doc.main.lst"
echo -n >"$MAINDOCFILES"
for f in AUTHORS ChangeLog COPYING NEWS README TODO data/conky.conf; do
    ff=$(basename "$f")
    install -D -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$ff"
    echo "%doc %{_docdir}/%{name}/$ff" >>"$MAINDOCFILES"
done
DOCDOCFILES="$PWD/doc.doc.lst"
echo -n >"$DOCDOCFILES"
for f in doc/*.html; do
    ff=$(basename "$f")
    install -D -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$ff"
    echo "%doc %{_docdir}/%{name}/$ff" >>"$DOCDOCFILES"
done

%if %with_lua_extra
rm -rf "%{buildroot}%{_libdir}/conky"/*.{a,la}
%else
install -d "%{buildroot}%{_libdir}/conky"
%endif

%clean
%{?buildroot:rm -rf %{buildroot}}

%files -f doc.main.lst
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}
%dir %{_sysconfdir}/conky
%config(noreplace) %{_sysconfdir}/conky/conky.conf
%config(noreplace) %{_sysconfdir}/conky/conky_no_x11.conf
%{_bindir}/conky
%doc %{_mandir}/man1/conky.1%{ext_man}
%{_datadir}/applications/%{name}.desktop
%dir %{_libdir}/conky

%if %with_lua_extra
%files cairo
%defattr(-,root,root)
%{_libdir}/conky/libcairo.so
%{_libdir}/conky/libcairo.so.*

%files imlib2
%defattr(-,root,root)
%{_libdir}/conky/libimlib2.so
%{_libdir}/conky/libimlib2.so.*
%endif #with_lua_extra

%files doc -f doc.doc.lst
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}

%files vim
%defattr(-,root,root)
%dir %{_datadir}/vim/site
%dir %{_datadir}/vim/site/ftdetect
%{_datadir}/vim/site/ftdetect/conkyrc.vim
%dir %{_datadir}/vim/site/syntax
%{_datadir}/vim/site/syntax/conkyrc.vim

%files nano
%defattr(-,root,root)
%dir %{_datadir}/nano
%{_datadir}/nano/conky.nanorc

%if 0%{?packman_bs}
%files feature-audacious
%defattr(-,root,root)
%doc README.feature-audacious

%files feature-nvidia
%defattr(-,root,root)
%doc README.feature-nvidia
%endif

%changelog
* Fri Nov  9 2012 i@marguerite.su
- merged PMBS changes here. enabled more options.(OBS compatible)
- add dependency imlib2-loaders for conky-imlib2.
  or conky will keep warning can't load images.
- add two patches from debian which also confirmed by user
  please_try_again.
  * fix-apcupsd.patch, revert broken apcupsd code to previous
    working version.
  * fix-CVE-2011-3616.patch. avoid rewriting an arbitrary user file
    already upstreamed. but not in 1.9.0. remove next release.
* Sun Oct 21 2012 pascal.bleser@opensuse.org
- merged back with my changes for SLES build compatibility
* Thu Jun 21 2012 toganm@opensuse.org
- Update to 1.9.0 for changes please see
  http://conky.sourceforge.net/changelog.html
  * reworked conky-libiw_with_libm.patch as conky-1.9.0-libiw_with_libm.patch
  * removed conky-fix-curl-FTBFS.patch as fixed by upstream
* Wed Feb 29 2012 cfarrell@suse.com
- license update: GPL-3.0+
  See the COPYING file
* Mon Jan 30 2012 coolo@suse.com
- use lua51 on factory
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Sep 29 2011 pascal.bleser@opensuse.org
- add cairo and imlib support where tolua++ is available,
  built as subpackages (conky-cairo and conky-imlib2)
- add patch to add -lm when linking against libiw, which is required by some
  more recent versions of libiw
* Mon Sep 26 2011 pascal.bleser@opensuse.org
- fix build issue with files in conky-doc
* Mon Sep 26 2011 nmarques@opensuse.org
- Add conky-fix-curl-FTBFS.patch: remove deprecated curl/types.h
  to fix FTBFS with newer versions of curl.
  Upstream: http://tinyurl.com/4x76bbx
* Fri Oct  8 2010 pascal.bleser@opensuse.org
- dropped conky-getaddrinfo.patch, was merged upstream
  (PATCH-FIX-OPENSUSE conky-getaddrinfo.patch fix-for-opensuse-specific-things.patch sf#3045085 pascal.bleser@opensuse.org)
- update to 1.8.1:
  * allow method to pass execgraph arguments containing spaces
  * abort curl transfers if they drop below 1000B/s for more than 60s
  * fix short_units for below kilo values
  * when we have a failure in mail thread, sleep for a bit
  * improve failure handling in mail threads
  * when we have a failure in the mail thread, lookup the hostname again in
    case the failure is due odd to DNS changes, or some other madness
  * fix segfault in ccurl_thread.c
  * fix crash in mail stuff due to bad free()
  * fix segfault in i8k (sf.net #3007167)
  * use getaddrinfo instead of gethostbyname: patches conky to use getaddrinfo
    instead of gethostbyname everywhere. gethostbyname is rather flawed and
    doesn't support IPv6 properly. Patch contributed by Pascal Bleser.
  * fix 'nvidia with ncurses segfaults' (sf.net #3006233)
  * make $fs_used_perc and $fs_bar report used space correctly; they reported
    fs->size - fs->avail, which is not correct if fs has super-user reserved
    blocks; note that now $fs_used_perc and $fs_free_perc need not add up to
    100%%, but that is consistent with what $fs_used and $fs_free do
  * fix buffer overflows in eve.c (sf.net #3034056)
  * fix bug where IMAP doesn't refresh counts after IDLE timeout
  * fix segfault in mail folder (SF: 3007493)
  * fix alignment ($align[rc]) issue for exec & lua objects
  * small build fix & zero playtime and progress bars when XMMS2 playback is stopped
  * fix tiny memleak when $top is used wrong
  * ${top}, ${top_mem} and ${top_time} are now recognized as variables; the
    parts of code doing this were in a #ifdef __linux__; the total CPU time of
    processes (${top} with "time" argument) is now printable, and ${top_time}
    works
  * fix battery_bar not parsing arguments correctly (sf: #2998034, lp: #569195)
  * bugfix: RSS interval was in secs instead of mins
  * bugfix: $alignr only worked on the first line of $execp, $execpi, $lua and $lua_parse
  * bugfix: memory and thread-deleting problems
  * bugfix: read_tcp treated a succesfull connection as failed and vice versa
  * add $nodename_short
  * bugfix: adding/removing use_xft in the config had no effect unless you
    restarted conky, reloading the config was not enough
  * fix building with Audacious >= 2.3
  * bugfix: mixerbar showed wrong values
  * bugfix: ac-adapter is sometimes called ADP1 in sysfs instead of AC
  * bugfix: battery_bar should also work without argument
  * bugfix: When the first line behind TEXT was a comment, the start of the
    second line wasn't parsed
  * fix X error when border_width is <1
  * fix device name parsing for diskio variables
  * fix bug in $if_existing
* Sun Jul  4 2010 pascal.bleser@opensuse.org
- update to 1.8.0
- split out -doc subpackage
- package vim and nano syntax highlighting configuration files into subpackages
  (instead of packaging them under the docdir)
* Wed Sep 30 2009 pascal.bleser@opensuse.org
- update to 1.7.2:
  * fixed minor memleak in pop3/imap code on config reload
  * fix crash when using $if_match with objects that may return a null pointer
    (like $rss, $weather, or $curl before data is available)
  * removed alias config option due to brokenness
  * changed xoap parsing method to xpath, in preparation to include forecast
    data
  * update MPD elapsed/progress when stopped (sf.net #2792113)
  * overhauled RSS and weather, added $curl
  * added support for X alignment across multi-lined objects (i.e., using
    $alignr with $exec)
  * www.weather.com can now be used as well as a source of weather dataµ
  * added support for $desktop, $desktop_number and $desktop_name (sf.net
    [#2040528])
  * added support for $swapfree
  * improved Lua API (lua_read_parse has been removed in favour of the
    conky_parse() Lua API call)
  * introduced new Lua Cairo and Imlib2 bindings
  * added support for $weather (experimental)
  * remove newline with comment only lines in TEXT
  * improved parsing of graph arguments, removed "log"|"normal" arguments in
    favour of -l switch
  * fix escaping of comments in TEXT (sf.net #2813390)
  * fix segfault in to_real_path, it's sometimes called with the same source
    and dest without checking the length, causing a segfault
  * use the internal process list for if_running on Linux
* Sat Jun 13 2009 pascal.bleser@opensuse.org
- update to 1.7.1.1:
  * fixed a regression which causes fonts to not be rendered properly with
    certain types of windows
  * fix bug in comments within TEXT (where the line contains just '#') (sf.net
    [#2803586])
  * fix bug in $mails (sf.net #2802529)
* Tue Jun  9 2009 pascal.bleser@opensuse.org
- update to 1.7.1
* Sun May  3 2009 pascal.bleser@opensuse.org
- update to 1.7.0
* Tue Oct  7 2008 bwalle@suse.de
- fix build on Factory
* Wed Sep 17 2008 guru@unixtech.be
- update to 1.6.1
* Tue Jul 22 2008 guru@unixtech.be
- new upstream version
* Sun Mar 23 2008 guru@unixtech.be
- new upstream version
* Thu Dec  6 2007 guru@unixtech.be
- new upstream version
* Wed Oct  3 2007 guru@unixtech.be
- update to 1.4.7
- moved to openSUSE Build Service
* Wed Jan  3 2007 guru@unixtech.be
- new upstream version
* Sat Sep  2 2006 guru@unixtech.be
- new upstream version
* Wed Feb 15 2006 guru@unixtech.be
- new upstream version
* Mon Jan  2 2006 guru@unixtech.be
- removed cairo flags, as removed from conky codebase
- new upstream version
- rewrote spec file
* Tue Nov  1 2005 guru@unixtech.be
- new package
